Description
Plots the cases data with a line whenever the forward simulation is seeded using the real data.
Usage
plotbreaks(data, threshold)
Arguments
data
Data frame with the cases vector.
threshold
The epidemic threshold, i.e. the number of cases required to spark a new outbreak in the model.